package com.itbaizhan.travel.controller.backstage;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.itbaizhan.travel.bean.RoleWithStatus;
import com.itbaizhan.travel.pojo.Admin;
import com.itbaizhan.travel.service.AdminService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.ModelAndView;

import java.util.List;

@Controller
@RequestMapping("/backstage/admin")
public class AdminController {
    @Autowired
    private AdminService adminService;
    //注意属性的访问限定修饰符为private

    @RequestMapping("/all")
    //使用ModelAndView作为返回值既可以返回页面也可以返回数据
    public ModelAndView all(@RequestParam(defaultValue = "1")int page,
                            @RequestParam(defaultValue = "10")int size){
        ModelAndView modelAndView = new ModelAndView();
        Page<Admin> adminPage = adminService.findPage(page, size);
        //从数据库中查询
        modelAndView.addObject("adminPage",adminPage);//将数据放入ModelAndView中
        modelAndView.setViewName("/backstage/admin_all");//设置跳转的页面
        return modelAndView;
        //点击用户管理时，会进入AdminController中的all方法中，然后从数据库中查询数据，通过modelAndView将数据发送到并跳转到admin_all页面。
    }

    @RequestMapping("/add")
    //捕获backstage/admin/add路径提交的表单
    //但是怎么把admin和表单中的内容对应起来呢？
    //好像是根据数据库中列名直接对应表单中input标签的name属性
    public String add(Admin admin){
        adminService.add(admin);
        return "redirect:/backstage/admin/all";//完成添加操作后，重定向到用户管理页面
    }


    @RequestMapping("/edit")//当admin_all页面中的修改按钮被点击后，捕获backstage/admin/edit，并查询管理员，跳转到修改页面
    public ModelAndView edit(Integer aid){//因为需要将管理员信息放到页面中展示，所以返回值用ModelAndView，方便传输数据和跳转页面
        Admin admin = adminService.findById(aid);
        ModelAndView modelAndView = new ModelAndView();
        modelAndView.addObject("admin",admin);//向modelAndView中添加数据
        modelAndView.setViewName("/backstage/admin_edit");//跳转到admin_edit页面
        return modelAndView;
    }

    @RequestMapping("/update")//捕获backstage/admin/update路径提交的表单
    public String update(Admin admin){
        adminService.update(admin);
        return "redirect:/backstage/admin/all";//完成添加操作后，重定向到用户管理页面
    }

    @RequestMapping("/desc")
    public ModelAndView desc(Integer aid){
        ModelAndView modelAndView = new ModelAndView();
        Admin admin = adminService.findDesc(aid);
        modelAndView.addObject("admin",admin);
        modelAndView.setViewName("/backstage/admin_desc");
        return modelAndView;
    }

    @RequestMapping("/findRole")//根据用户aid查询用户所拥有的角色和不拥有的角色
    public ModelAndView findRole(Integer aid){
        ModelAndView modelAndView = new ModelAndView();
        List<RoleWithStatus> roleWithStatusList = adminService.findRole(aid);
        modelAndView.addObject("roleWithStatusList",roleWithStatusList);
        modelAndView.addObject("aid",aid);
        modelAndView.setViewName("/backstage/admin_role");
        return modelAndView;
    }

    @RequestMapping("/updateRole")//修改用户角色，需要先将原有角色删除，重新赋予角色
    public String updateRole(Integer aid,Integer[] rids){//视频中第二个参数写作ids，所以为什么写作rids不行？
        adminService.updateRoles(aid,rids);
        return "redirect:/backstage/admin/all";
    }

    @RequestMapping("/updateStatus")//修改用户状态，点击“启用/禁用”按钮后，会通过get方式将aid提交到这个Controller上
    public String updateStatus(Integer aid){//2022年11月29日，成功实现“启用/禁用”按钮修改用户状态功能。
        adminService.updateStatus(aid);//调用adminService中的修改状态方法
        return "redirect:/backstage/admin/all";
    }

}
