package com.itbaizhan.travel.controller.backstage;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.itbaizhan.travel.bean.PermissionWithStatus;
import com.itbaizhan.travel.pojo.Role;
import com.itbaizhan.travel.service.RoleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.ModelAndView;

import java.util.List;

@Controller
@RequestMapping("/backstage/role")
public class RoleController {//后台角色管理器
    @Autowired
    private RoleService roleService;

    @RequestMapping("/all")
    public ModelAndView all(@RequestParam(defaultValue = "1") int page, @RequestParam(defaultValue = "10")int size){//为参数设置默认值
        Page<Role> rolePage = roleService.findPage(page,size);//通过roleService查到分页数据
        ModelAndView modelAndView = new ModelAndView();
        modelAndView.addObject("rolePage",rolePage);
        modelAndView.setViewName("/backstage/role_all");
        return modelAndView;
    }

    @RequestMapping("/add")
    public String add(Role role){
        roleService.add(role);
        return "redirect:/backstage/role/all";
    }

    @RequestMapping("/edit")//实现编辑功能，需要从数据库中获得角色原本的角色名和角色详情然后显示到前端。
    public ModelAndView edit(Integer rid){//具体流程：点击role_all页面的修改按钮后会，会触发本方法，然后从数据库中查询数据，返回到role_edit页面。
        Role role = roleService.findById(rid);
        ModelAndView modelAndView = new ModelAndView();
        modelAndView.addObject("role",role);
        modelAndView.setViewName("/backstage/role_edit");
        return modelAndView;
    }

    @RequestMapping("/update")//有一点不太明白，update和edit有什么区别？两者好像很相近
    public String update(Role role){//在role_edit页面点击保存按钮后，会将前端提交的roleName、roleDesc包装成role对象，到数据库中将rid对应的内容更新。
        roleService.update(role);
        return "redirect:/backstage/role/all";
    }

    @RequestMapping("/delete")//根据用户rid删除用户
    public String delete(Integer rid){//管理员点击删除按钮时访问/backstage/role/delete，并将rid作为参数上传
        roleService.delete(rid);
        return "redirect:/backstage/role/all";
    }

    @RequestMapping("/findPermission")
    public ModelAndView findRole(Integer rid){
        List<PermissionWithStatus> permissionWithStatusList = roleService.findPermission(rid);
        ModelAndView modelAndView = new ModelAndView();
        modelAndView.addObject("permissionWithStatusList",permissionWithStatusList);
        modelAndView.addObject("rid",rid);//查询后需要对权限进行修改，所以需要将rid也传入前端页面
        modelAndView.setViewName("/backstage/role_permission");
        return modelAndView;
    }

    @RequestMapping("/updatePermission")
    public String updatePermission(Integer rid,Integer[] pids){
        roleService.updatePermissions(rid,pids);
        return "redirect:/backstage/role/all";//应该在修改角色的权限后，跳转到角色管理页面
    }
}
