package com.itbaizhan.travel.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.itbaizhan.travel.bean.RoleWithStatus;
import com.itbaizhan.travel.mapper.AdminMapper;
import com.itbaizhan.travel.mapper.RoleMapper;
import com.itbaizhan.travel.pojo.Admin;
import com.itbaizhan.travel.pojo.Role;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service//这个注解有什么作用来着？
public class AdminService {
//在这个类中使用Mapper
    @Autowired//自动注入
    private AdminMapper adminMapper;
    @Autowired
    private RoleMapper roleMapper;

    //分页查询管理员
    public Page<Admin> findPage(int page,int size){
        Page selectPage = adminMapper.selectPage(new Page(page, size), null);
        //参数一：以page和size创建的Page对象
        //参数二：查询条件，null即表示没有特殊条件，查询所有内容
        return selectPage;
        //返回页面对象
    }

    //新增管理员方法
    //adminMapper中已经有插入方法，所以不用编写AdminMapper，直接在AdminService中编写新增方法，调用insert方法。
    //然后在adminController中调用add方法就能完成新建管理员的操作。
    public void add(Admin admin){
        adminMapper.insert(admin);
    }

    //根据id查询管理员
    // （根据id查询到管理员，然后将数据传入修改页面，同时管理员id作为隐藏的input标签，不能修改管理员id）
    //思考为什么参数类型要用Integer而不是int？
    public Admin findById(Integer aid){
        return adminMapper.selectById(aid);//selectById也是adminMapper自带的方法
    }

    //根据id修改管理员
    //配合admin_edit页面，对数据库中的对应内容进行修改
    public void update(Admin admin){
        adminMapper.updateById(admin);//所以updateById方法的原理是根据admin的id，按照admin传入的内容对数据库中对应的管理员进行修改吗？
    }

    //根据aid查询用户详情
    public Admin findDesc(Integer aid){
        Admin desc = adminMapper.findDesc(aid);
         return desc;
    }

    //查询用户的角色情况
    //从admin_role表中，根据用户aid查询，返回带状态的角色的结果集
    public List<RoleWithStatus> findRole(Integer aid){
        //查询所有角色
        List<Role> roleList = roleMapper.selectList(null);//selestList是Mybatis自带的方法，参数是过滤条件，空参null则表示查询所有
        //查询用户拥有的角色
        List<Integer> rids = roleMapper.findRoleIdByAdmin(aid);
        //构建带有角色状态的角色集合
        List<RoleWithStatus> roleWithStatusList=new ArrayList<>();
        for (Role role: roleList) {
            //遍历创建带有状态的角色
            RoleWithStatus roleWithStatus=new RoleWithStatus();
            //需要将roleList中每个role对象的rid、roleName和roleDesc复制到roleWithStatusList中的对应roleWithStatus对象中
            //可以通过get和set方法将属性一个一个复制
            //此处使用更方便快捷的方法
            BeanUtils.copyProperties(role,roleWithStatus);//第一个参数为源对象
            //如果用户拥有该角色，就将状态变量设置为true
            if(rids.contains(role.getRid())){//为什么lombok的@Data注解没有引入get和set方法？已提问，未解答（好像测试的时候也没有报错，能运行。。。。）
                roleWithStatus.setAdminHas(true);
            }else{
                roleWithStatus.setAdminHas(false);
            }
            roleWithStatusList.add(roleWithStatus);
        }
        return roleWithStatusList;
    }

    public void updateRoles(Integer aid,Integer[] rids){//修改用户角色，先删除原有的所有角色，然后重新添加
        adminMapper.deleteAdminAllRoles(aid);//删除用户的所有角色
        for (Integer rid : rids) {//重新添加角色
            adminMapper.addAdminRole(aid,rid);//2022年11月28日,报错空指针异常,查明原因并不是AdminMapper.xml文件中, <insert id="addAdminRole">拼写错误,修改后,还是报错空指针异常,明天请教老师
        }
    }

    public void updateStatus(Integer aid){// 修改用户状态，通过Controller读取到前端的aid，传入adminService中，然后在数据库中对状态变量取反
        Admin admin = adminMapper.selectById(aid);//alt+两次回车，快速创建对象
        admin.setStatus(!admin.isStatus());
        adminMapper.updateById(admin);
    }

}
