package com.itbaizhan.travel.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.itbaizhan.travel.bean.PermissionWithStatus;
import com.itbaizhan.travel.mapper.PermissionMapper;
import com.itbaizhan.travel.mapper.RoleMapper;
import com.itbaizhan.travel.pojo.Permission;
import com.itbaizhan.travel.pojo.Role;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class RoleService {
    @Autowired
    private RoleMapper roleMapper;
    @Autowired
    private PermissionMapper permissionMapper;

    public Page<Role> findPage(int page, int size){//分页查询功能
        Page selectPage = roleMapper.selectPage(new Page(page,size),null);//null表示分页查询时，没有特殊条件
        return selectPage;
    }

    public void add(Role role){//新增角色功能，无返回值
        roleMapper.insert(role);
    }

    public Role findById(Integer rid){//根据角色的rid查询角色
        return roleMapper.selectById(rid);
    }

    public void update(Role role){//根据role中的角色rid修改角色
        roleMapper.updateById(role);
    }

    public void delete(Integer rid){//根据rid删除角色
        roleMapper.deleteById(rid);
    }

    //查询角色权限情况
    public List<PermissionWithStatus> findPermission(Integer rid){
        //查询所有权限
        List<Permission> permissions = permissionMapper.selectList(null);//null表示没有特殊条件
        //查询角色拥有的所有权限的id
        List<Integer> pids = permissionMapper.findPermissionIdByRole(rid);
        //带有状态的权限集合
        List<PermissionWithStatus> permissionWithStatusList = new ArrayList();
        //遍历所有权限
        for (Permission permission:permissions) {
            //创建带有状态的权限
            PermissionWithStatus permissionWithStatus = new PermissionWithStatus();
            //将权限属性复制给带有状态的权限，借助BeanUtils工具类
            BeanUtils.copyProperties(permission,permissionWithStatus);
            if(pids.contains(permission.getPid())){
                permissionWithStatus.setRoleHas(true);
            }else{
                permissionWithStatus.setRoleHas(false);//虽然报错但是可以正常运行
            }
            permissionWithStatusList.add(permissionWithStatus);
        }
        return permissionWithStatusList;
    }

    public void updatePermissions(Integer rid,Integer[] pids){
        roleMapper.deleteRoleAllPermission(rid);//删除角色的所有权限
        for (Integer pid :
                pids) {
            roleMapper.addRolePermission(rid, pid);
        }
    }
}
